@@ -14,6 +14,8 @@ from mitosheet.user.db import set_user_field
 from mitosheet.user import initialize_user
 from mitosheet.user.schemas import UJ_MITOSHEET_PRO, UJ_MITOSHEET_TELEMETRY, UJ_USER_EMAIL
 from mitosheet.startup.startup_utils import create_startup_file, remove_startup_file
+from mitosheet.user.utils import check_pro_acccess_code
+
 
 def main() -> None:
     """
@@ -42,9 +44,17 @@ def main() -> None:
             set_user_field(UJ_MITOSHEET_TELEMETRY, True)
             print("Logging turned on!")
         if sys.argv[-1] == 'turnoffpro':
-            print("Turning on Mitosheet pro")
+            print("Turning off Mitosheet pro")
             set_user_field(UJ_MITOSHEET_PRO, False)
             print("Mitosheet Pro is false!")
+        if sys.argv[-2] == 'turnonpro':
+            print("Turning on Mitosheet pro", sys.argv[-1])
+            if check_pro_acccess_code(sys.argv[-1].strip()):
+                set_user_field(UJ_MITOSHEET_PRO, True)
+                set_user_field(UJ_MITOSHEET_TELEMETRY, False)
+                print("Mitosheet Pro is now active!")
+            else:
+                print("Invalid access code...")
         if sys.argv[-1] == 'clearemail':
             print("Clearing email")
             set_user_field(UJ_USER_EMAIL, '')
