@@ -5,12 +5,11 @@
 # Distributed under the terms of the GPL License.
 
 from mitosheet.saved_analyses.save_utils import (
-    read_and_upgrade_analysis, write_save_analysis_file,
-    delete_saved_analysis, rename_saved_analysis, 
+    read_and_upgrade_analysis, write_analysis,
+    delete_saved_analysis, rename_saved_analysis, register_analysis,
     _get_all_analysis_filenames, _delete_analyses,
     SAVED_ANALYSIS_FOLDER, read_analysis,
-    get_steps_obj_for_saved_analysis, get_analysis_exists, 
-    get_saved_analysis_string
+    make_steps_json_obj, get_analysis_exists
 )
 from mitosheet.saved_analyses.upgrade import is_prev_version
 from mitosheet.saved_analyses.upgrade import upgrade_saved_analysis_to_current_version
