@@ -9,8 +9,11 @@ from time import perf_counter
 from typing import Any, Dict, List, Optional, Set, Tuple
 
 import pandas as pd
+from mitosheet.code_chunks.code_chunk import CodeChunk
+from mitosheet.code_chunks.step_performers.concat_code_chunk import ConcatCodeChunk
 from mitosheet.state import DATAFRAME_SOURCE_CONCAT, State
 from mitosheet.step_performers.step_performer import StepPerformer
+from mitosheet.step_performers.utils import get_param
 
 
 class ConcatStepPerformer(StepPerformer):
@@ -25,24 +28,17 @@ class ConcatStepPerformer(StepPerformer):
     @classmethod
     def step_type(cls) -> str:
         return 'concat'
-    
-    @classmethod
-    def step_display_name(cls) -> str:
-        return 'Concatenated Dataframes'
 
     @classmethod
     def saturate(cls, prev_state: State, params: Dict[str, Any]) -> Dict[str, Any]:
         return params
 
     @classmethod
-    def execute( # type: ignore
-        cls,
-        prev_state: State,
-        join: str, # inner | outter
-        ignore_index: bool,
-        sheet_indexes: List[int],
-        **params
-    ) -> Tuple[State, Optional[Dict[str, Any]]]:
+    def execute(cls, prev_state: State, params: Dict[str, Any]) -> Tuple[State, Optional[Dict[str, Any]]]:
+
+        join = get_param(params, 'join') # inner | outter
+        ignore_index = get_param(params, 'ignore_index') # inner | outter
+        sheet_indexes = get_param(params, 'sheet_indexes') # inner | outter
 
         post_state = prev_state.copy()
 
@@ -64,39 +60,16 @@ class ConcatStepPerformer(StepPerformer):
         }
 
     @classmethod
-    def transpile( # type: ignore
+    def transpile(
         cls,
         prev_state: State,
         post_state: State,
+        params: Dict[str, Any],
         execution_data: Optional[Dict[str, Any]],
-        join: str, # inner | outter
-        ignore_index: bool,
-        sheet_indexes: List[int]
-    ) -> List[str]:
-
-        df_names_to_concat = [post_state.df_names[sheet_index] for sheet_index in sheet_indexes]
-        df_new_name = post_state.df_names[len(post_state.dfs) - 1]
-
-        if len(df_names_to_concat) == 0:
-            return [f'{df_new_name} = pd.DataFrame()']
-        else:
-            return [
-                f"{df_new_name} = pd.concat([{', '.join(df_names_to_concat)}], join=\'{join}\', ignore_index={ignore_index})"
-            ]
-
-    @classmethod
-    def describe( # type: ignore
-        cls,
-        join: str, # inner | outter
-        ignore_index: bool,
-        sheet_indexes: List[int],
-        df_names=None,
-        **params
-    ) -> str:
-        if df_names is not None:
-            df_names_to_concat = [df_names[sheet_index] for sheet_index in sheet_indexes]
-            return f'Concated ' + ", ".join(df_names_to_concat)
-        return f'Concated dataframes'
+    ) -> List[CodeChunk]:
+        return [
+            ConcatCodeChunk(prev_state, post_state, params, execution_data)
+        ]
     
     @classmethod
     def get_modified_dataframe_indexes( # type: ignore
