@@ -4,6 +4,7 @@
 # Copyright (c) Saga Inc.
 # Distributed under the terms of the GPL License.
 from abc import ABC, abstractmethod
+from mitosheet.code_chunks.code_chunk import CodeChunk
 from mitosheet.state import State
 from typing import Any, Dict, List, Optional, Set, Tuple
  
@@ -30,15 +31,6 @@ class StepPerformer(ABC, object):
         the step and bump the version.
         """
         pass
-
-    @classmethod
-    @abstractmethod
-    def step_display_name(cls) -> str:
-        """
-        The name of the step that is displayed to the user
-        in the frontend.
-        """
-        pass
     
     @classmethod
     def step_event_type(cls) -> str:
@@ -49,7 +41,7 @@ class StepPerformer(ABC, object):
         return f'{cls.step_type()}_edit'
 
     @classmethod
-    def saturate(cls, prev_state: State, params: Any) -> Dict[str, str]:
+    def saturate(cls, prev_state: State, params: Dict[str, Any]) -> Dict[str, Any]:
         """
         Given the parameters of the step, will saturate the event with
         more parameters based on the passed prev_state. 
@@ -59,7 +51,7 @@ class StepPerformer(ABC, object):
 
     @classmethod
     @abstractmethod
-    def execute(cls, prev_state: State, **params: Any) -> Tuple[State, Optional[Dict[str, Any]]]:
+    def execute(cls, prev_state: State, params: Dict[str, Any]) -> Tuple[State, Optional[Dict[str, Any]]]:
         """
         Execute always returns the post_state, and optionally returns a dictionary
         of execution_data, which is data that may be useful to the transpiler in
@@ -72,20 +64,16 @@ class StepPerformer(ABC, object):
         pass
 
     @classmethod
-    @abstractmethod
-    def transpile(cls, prev_state: State, post_state: State, **params: Any) -> List[str]:
+    def transpile(
+        cls,
+        prev_state: State,
+        post_state: State,
+        params: Dict[str, Any],
+        execution_data: Optional[Dict[str, Any]],
+    ) -> List[CodeChunk]:
         """
-        Returns a list of the Python code lines that corresponds to this 
-        step being executed.
-        """
-        pass
-
-    @classmethod
-    @abstractmethod
-    def describe(cls, **params: Any) -> str:
-        """
-        Describes the step in a single sentence, usually for comments or for presentation
-        to the user in the frontend.
+        Returns a list of the CodeChunks that correspond to this 
+        step being executed
         """
         pass
 
